@@ -40,6 +40,8 @@ class TracPost(Plugin):
 		pp = pprint.PrettyPrinter(indent=4)
 	       	ticket_id = rpc_srv.ticket.create(group.message, "{{{\n" + str(pp.pformat(group.data)) + "\n}}}\n\nSee Sentry Page @ http://sentry.joinerysoft-directory.co.uk/jms/group/" + str(event.group_id), {'priority':"minor",}, False)
 		print "New Ticket - " + str(ticket_id)
+	else:
+		print "Something Went Wrong"
 
     def actions(self, request, group, action_list, **kwargs):
 	action_list.append(('Send to Trac', 'http://google.com'))
